---
title: eQTL Catalogue
---

The [eQTL Catalogue](https://www.ebi.ac.uk/eqtl/) aims to provide unified gene, protein expression and splicing Quantitative Trait Loci (QTLs) from all available human public studies.

It serves as the ultimate resource of molecular QTLs that we use for colocalization and target prioritization.
